# openapi-client
[1MSG.IO](https://1msg.io/) is the perfect WhatsApp management tool for your business. With us you get full access to the official Whatsapp API/webhooks.

Every API request must contain an Authorize HTTP header with a token. 
This is your channel token, which can be found in your channel project on your profile page.
Please do not give the token to anyone or post it publicly.

The authorization token must be added to each request in the GET parameter 'token' and always passed to query string (?token={your_token}).
Parameters in GET queries pass query string. Parameters in POST requests — through the JSON-encoded request body. 

All 'send' methods (except /sendTemplate) will only work when the dialog session with the user is open. Some of our solutions simplify and avoid such limitations, but we urge you to pay more attention to this detail

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.39.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install one_msg_waba_sdk 
```
(you may need to run `pip` with root permission: `sudo pip install one_msg_waba_sdk `)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import os
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.1msg.io/YOUR_INSTANCE_NUMBER
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://api.1msg.io/YOUR_INSTANCE_NUMBER"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: token
configuration.api_key['token'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['token'] = 'Bearer'


# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ChannelApi(api_client)

    try:
        # Get Commerce Settings
        api_response = api_instance.get_commerce()
        print("The response of ChannelApi->get_commerce:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ChannelApi->get_commerce: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.1msg.io/YOUR_INSTANCE_NUMBER*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ChannelApi* | [**get_commerce**](docs/ChannelApi.md#get_commerce) | **GET** /commerce | Get Commerce Settings
*ChannelApi* | [**get_extended_statistics**](docs/ChannelApi.md#get_extended_statistics) | **GET** /extendedStatistics | Get Extended Channel statistics
*ChannelApi* | [**get_me**](docs/ChannelApi.md#get_me) | **GET** /me | Get Profile Info
*ChannelApi* | [**get_settings**](docs/ChannelApi.md#get_settings) | **GET** /settings | Get Settings
*ChannelApi* | [**get_statistics**](docs/ChannelApi.md#get_statistics) | **GET** /statistics | Get Channel statistics
*ChannelApi* | [**get_status**](docs/ChannelApi.md#get_status) | **GET** /status |  Get Status
*ChannelApi* | [**output_ip**](docs/ChannelApi.md#output_ip) | **GET** /outputIP | Get channel server IP
*ChannelApi* | [**set_me**](docs/ChannelApi.md#set_me) | **POST** /me | Change user info
*ChannelApi* | [**set_settings**](docs/ChannelApi.md#set_settings) | **POST** /settings | Set settings
*MediaApi* | [**upload_media**](docs/MediaApi.md#upload_media) | **POST** /uploadMedia | Upload media &amp; get mediaId
*MessagingApi* | [**messages_list**](docs/MessagingApi.md#messages_list) | **GET** /messages | Get messages list
*MessagingApi* | [**read_message**](docs/MessagingApi.md#read_message) | **POST** /readMessage | Mark message as read
*MessagingApi* | [**send_contact**](docs/MessagingApi.md#send_contact) | **POST** /sendContact | Send a Contact
*MessagingApi* | [**send_file**](docs/MessagingApi.md#send_file) | **POST** /sendFile | Send a File
*MessagingApi* | [**send_list**](docs/MessagingApi.md#send_list) | **POST** /sendList | Send List Message
*MessagingApi* | [**send_location**](docs/MessagingApi.md#send_location) | **POST** /sendLocation | Send a Location
*MessagingApi* | [**send_message**](docs/MessagingApi.md#send_message) | **POST** /sendMessage | Send a Message
*ProductsCatalogsApi* | [**send_product**](docs/ProductsCatalogsApi.md#send_product) | **POST** /sendProduct | Send a Product
*ProductsCatalogsApi* | [**set_commerce**](docs/ProductsCatalogsApi.md#set_commerce) | **POST** /commerce | Set Commerce Settings
*TemplatesApi* | [**add_template**](docs/TemplatesApi.md#add_template) | **POST** /addTemplate | Create template
*TemplatesApi* | [**remove_template**](docs/TemplatesApi.md#remove_template) | **POST** /removeTemplate | Remove template
*TemplatesApi* | [**send_template**](docs/TemplatesApi.md#send_template) | **POST** /sendTemplate | Send Template Message
*TemplatesApi* | [**templates_list**](docs/TemplatesApi.md#templates_list) | **GET** /templates | Get templates list
*WebhooksApi* | [**ack_hook_info**](docs/WebhooksApi.md#ack_hook_info) | **GET** /hookInfo | Check ACKs
*WebhooksApi* | [**set_webhook**](docs/WebhooksApi.md#set_webhook) | **POST** /webhook | Set webhook


## Documentation For Models

 - [Ack](docs/Ack.md)
 - [AddTemplateRequest](docs/AddTemplateRequest.md)
 - [ChannelExtendedStatistics](docs/ChannelExtendedStatistics.md)
 - [ChannelExtendedStatisticsInner](docs/ChannelExtendedStatisticsInner.md)
 - [ChannelStatistics](docs/ChannelStatistics.md)
 - [ChannelStatus](docs/ChannelStatus.md)
 - [ChatIdProp](docs/ChatIdProp.md)
 - [Commerce](docs/Commerce.md)
 - [CommerceParams](docs/CommerceParams.md)
 - [Contacts](docs/Contacts.md)
 - [ContactsContactsInner](docs/ContactsContactsInner.md)
 - [ContactsRequest](docs/ContactsRequest.md)
 - [GetAckInfo](docs/GetAckInfo.md)
 - [GetAckInfoHooksInner](docs/GetAckInfoHooksInner.md)
 - [GetCommerce](docs/GetCommerce.md)
 - [GetCommerceInner](docs/GetCommerceInner.md)
 - [GetIP](docs/GetIP.md)
 - [GetMe](docs/GetMe.md)
 - [GetMe401Response](docs/GetMe401Response.md)
 - [GetMessages](docs/GetMessages.md)
 - [GetMessagesMessagesInner](docs/GetMessagesMessagesInner.md)
 - [GetTemplates](docs/GetTemplates.md)
 - [GetTemplatesTemplatesInner](docs/GetTemplatesTemplatesInner.md)
 - [MeComponents](docs/MeComponents.md)
 - [MediaId](docs/MediaId.md)
 - [Message](docs/Message.md)
 - [MessageIdProp](docs/MessageIdProp.md)
 - [PhoneProp](docs/PhoneProp.md)
 - [ReadMessageRequest](docs/ReadMessageRequest.md)
 - [RemoveTemplateRequest](docs/RemoveTemplateRequest.md)
 - [SendContactRequest](docs/SendContactRequest.md)
 - [SendFileRequest](docs/SendFileRequest.md)
 - [SendListRequest](docs/SendListRequest.md)
 - [SendListRequestAllOfRows](docs/SendListRequestAllOfRows.md)
 - [SendListRequestAllOfSections](docs/SendListRequestAllOfSections.md)
 - [SendLocationRequest](docs/SendLocationRequest.md)
 - [SendMessageRequest](docs/SendMessageRequest.md)
 - [SendMessageStatus](docs/SendMessageStatus.md)
 - [SendProductRequest](docs/SendProductRequest.md)
 - [SendProductRequestAllOfAction](docs/SendProductRequestAllOfAction.md)
 - [SendProductRequestAllOfActionProductItems](docs/SendProductRequestAllOfActionProductItems.md)
 - [SendProductRequestAllOfActionSections](docs/SendProductRequestAllOfActionSections.md)
 - [SendTemplateRequest](docs/SendTemplateRequest.md)
 - [SendTemplateRequestAllOfCurrency](docs/SendTemplateRequestAllOfCurrency.md)
 - [SendTemplateRequestAllOfDateTime](docs/SendTemplateRequestAllOfDateTime.md)
 - [SendTemplateRequestAllOfDateTimeComponent](docs/SendTemplateRequestAllOfDateTimeComponent.md)
 - [SendTemplateRequestAllOfDateTimeUnixEpoch](docs/SendTemplateRequestAllOfDateTimeUnixEpoch.md)
 - [SendTemplateRequestAllOfLanguage](docs/SendTemplateRequestAllOfLanguage.md)
 - [SendTemplateRequestAllOfParams](docs/SendTemplateRequestAllOfParams.md)
 - [SetCommerce](docs/SetCommerce.md)
 - [SetMe](docs/SetMe.md)
 - [SetMeRequest](docs/SetMeRequest.md)
 - [SetSettings200Response](docs/SetSettings200Response.md)
 - [SetSettings200ResponseAllOfUpdate](docs/SetSettings200ResponseAllOfUpdate.md)
 - [SetWebhookStatus](docs/SetWebhookStatus.md)
 - [Settings](docs/Settings.md)
 - [TemplateCategoryProp](docs/TemplateCategoryProp.md)
 - [TemplateComponentsProp](docs/TemplateComponentsProp.md)
 - [TemplateComponentsPropInner](docs/TemplateComponentsPropInner.md)
 - [TemplateComponentsPropInnerButtonsInner](docs/TemplateComponentsPropInnerButtonsInner.md)
 - [TemplateLanguageProp](docs/TemplateLanguageProp.md)
 - [TemplateNamespaceField](docs/TemplateNamespaceField.md)
 - [UploadMedia](docs/UploadMedia.md)
 - [WebhookUrl](docs/WebhookUrl.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="token"></a>
### token

- **Type**: API key
- **API key parameter name**: token
- **Location**: URL query string


## Author

hello@1msg.io


